@@ -395,8 +395,10 @@ hitori_start_timer (Hitori *hitori)
 void
 hitori_pause_timer (Hitori *hitori)
 {
-	if (hitori->timeout_id > 0)
+	if (hitori->timeout_id > 0) {
 		g_source_remove (hitori->timeout_id);
+		hitori->timeout_id = 0;
+	}
 }
 
 void
@@ -436,7 +438,9 @@ main (int argc, char *argv[])
 	HitoriApplication *app;
 	int status;
 
+#if !GLIB_CHECK_VERSION (2, 35, 0)
 	g_type_init ();
+#endif
 
 	app = hitori_application_new ();
 	status = g_application_run (G_APPLICATION (app), argc, argv);
